within FluidDissipation.Examples.TestCases.PressureLoss;
model SeveralTestCases
  "Test cases of pressure loss functions for several devices"

  SI.Diameter d_hyd=0.1 "Hydraulic diameter";
  SI.Area A_cross=PI*d_hyd^2/4 "Cross sectional area";
  Real eta=1e-3 "Dynamic viscosity of Water";
  Real rho=1e3 "Density of Water";
  Real Re_cir=input_mflow.y*d_hyd/(eta*A_cross) "Circular geometry";
  Real Re_rec=input_mflow.y*d_hyd/(eta*d_hyd^2) "Rectangular geometry";
  Real vel_cir=input_mflow.y/(rho*A_cross) "Circular geometry";
  Real vel_rec=input_mflow.y/(rho*d_hyd^2) "Rectangular geometry";

  inner Modelica.Fluid.System system(p_ambient(displayUnit="Pa") = 100000,
      m_flow_small=0.01) annotation (extent=[80, -100; 100, -80], Placement(
        transformation(extent={{-200,-200},{-180,-180}})));

public
  Modelica.Blocks.Sources.Sine input_mflow(
    offset=0,
    freqHz=1,
    amplitude=10) annotation (extent=[-100, -52; -80, -32], Placement(
        transformation(extent={{-200,-12},{-180,8}})));

public
  Modelica.Blocks.Sources.RealExpression input_p(y=from_mflow.port_a.p) 
    annotation (extent=[-100, 0; -80, 20], Placement(transformation(extent={{0,
            156},{20,176}})));
  Modelica.Fluid.Sources.Boundary_pT IN_p(
    nPorts=1,
    T(displayUnit="K") = system.T_ambient,
    p(displayUnit="Pa") = system.p_ambient,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{40,158},{60,178}})));

  Modelica.Fluid.Sources.FixedBoundary OUT_dp(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={190,168})));

  Modelica.Fluid.Sources.FixedBoundary OUT_mflow(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={190,128})));

  Modelica.Fluid.Sources.MassFlowSource_T IN_mflow(
    T=system.T_ambient,
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,128})));

  Applications.PressureLoss.BendFlowModel from_dp(redeclare package Medium = 
        Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Bend.CurvedBend.CurvedBendFlowModel)
    "Calculate mass flow rate from pressure loss" 
    annotation (Placement(transformation(extent={{76,144},{124,192}})));

  Applications.PressureLoss.BendFlowModel from_mflow(redeclare package Medium
      = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Bend.CurvedBend.CurvedBendFlowModel)
    "Calculate pressure loss from mass flow rate" 
    annotation (Placement(transformation(extent={{76,104},{124,152}})));

public
  Modelica.Blocks.Sources.RealExpression input_p1(y=from_mflow1.port_a.p) 
    annotation (extent=[-100, 0; -80, 20], Placement(transformation(extent={{-198,
            76},{-178,96}})));
  Modelica.Fluid.Sources.Boundary_pT IN_p1(
    nPorts=1,
    T(displayUnit="K") = system.T_ambient,
    p(displayUnit="Pa") = system.p_ambient,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-158,78},{-138,98}})));
  Modelica.Fluid.Sources.FixedBoundary OUT_dp1(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={-8,88})));
  Modelica.Fluid.Sources.FixedBoundary OUT_mflow1(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={-8,48})));
  Modelica.Fluid.Sources.MassFlowSource_T IN_mflow1(
    T=system.T_ambient,
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-148,48})));
  Applications.PressureLoss.BendFlowModel from_dp1(redeclare package Medium = 
        Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Bend.EdgedBend.EdgedBendFlowModel)
    "Calculate mass flow rate from pressure loss" 
    annotation (Placement(transformation(extent={{-122,72},{-74,120}})));

  Applications.PressureLoss.BendFlowModel from_mflow1(redeclare package Medium
      = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Bend.EdgedBend.EdgedBendFlowModel)
    "Calculate pressure loss from mass flow rate" 
    annotation (Placement(transformation(extent={{-122,24},{-74,72}})));

public
  Modelica.Blocks.Sources.RealExpression input_p2(y=from_mflow2.port_a.p) 
    annotation (extent=[-100, 0; -80, 20], Placement(transformation(extent={{0,
            -4},{20,16}})));
  Modelica.Fluid.Sources.Boundary_pT IN_p2(
    nPorts=1,
    T(displayUnit="K") = system.T_ambient,
    p(displayUnit="Pa") = system.p_ambient,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{40,-2},{60,18}})));
  Modelica.Fluid.Sources.FixedBoundary OUT_dp2(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={190,8})));
  Modelica.Fluid.Sources.FixedBoundary OUT_mflow2(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={190,-32})));
  Modelica.Fluid.Sources.MassFlowSource_T IN_mflow2(
    T=system.T_ambient,
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,-32})));
  Applications.PressureLoss.ChannelFlowModel from_dp2(redeclare package Medium
      = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Channel.Overall.OverallFlowModel)
    "Calculate mass flow rate from pressure loss" 
    annotation (Placement(transformation(extent={{76,-8},{124,40}})));

  Applications.PressureLoss.ChannelFlowModel from_mflow2(redeclare package
      Medium = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare
      model FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Channel.Overall.OverallFlowModel)
    "Calculate pressure loss from mass flow rate" 
    annotation (Placement(transformation(extent={{76,-56},{124,-8}})));

public
  Modelica.Blocks.Sources.RealExpression input_p3(y=from_mflow3.port_a.p) 
    annotation (extent=[-100, 0; -80, 20], Placement(transformation(extent={{-200,
            -82},{-180,-62}})));
  Modelica.Fluid.Sources.Boundary_pT IN_p3(
    nPorts=1,
    T(displayUnit="K") = system.T_ambient,
    p(displayUnit="Pa") = system.p_ambient,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{-160,-80},{-140,-60}})));
  Modelica.Fluid.Sources.FixedBoundary OUT_dp3(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={-10,-70})));
  Modelica.Fluid.Sources.FixedBoundary OUT_mflow3(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={-10,-110})));
  Modelica.Fluid.Sources.MassFlowSource_T IN_mflow3(
    T=system.T_ambient,
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-150,-110})));
  Applications.PressureLoss.StraightPipeFlowModel from_dp3(redeclare package
      Medium = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare
      model FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.StraightPipe.Overall.OverallFlowModel)
    "Calculate mass flow rate from pressure loss" 
    annotation (Placement(transformation(extent={{-124,-86},{-76,-38}})));

  Applications.PressureLoss.StraightPipeFlowModel from_mflow3(redeclare package
      Medium = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare
      model FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.StraightPipe.Overall.OverallFlowModel)
    "Calculate pressure loss from mass flow rate" 
    annotation (Placement(transformation(extent={{-124,-134},{-76,-86}})));

public
  Modelica.Blocks.Sources.RealExpression input_p4(y=from_mflow4.port_a.p) 
    annotation (extent=[-100, 0; -80, 20], Placement(transformation(extent={{0,
            -160},{20,-140}})));
  Modelica.Fluid.Sources.Boundary_pT IN_p4(
    nPorts=1,
    T(displayUnit="K") = system.T_ambient,
    p(displayUnit="Pa") = system.p_ambient,
    use_p_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(extent={{40,-158},{60,-138}})));
  Modelica.Fluid.Sources.FixedBoundary OUT_dp4(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={190,-148})));
  Modelica.Fluid.Sources.FixedBoundary OUT_mflow4(
    p=system.p_ambient,
    T=system.T_ambient,
    nPorts=1,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={190,-188})));
  Modelica.Fluid.Sources.MassFlowSource_T IN_mflow4(
    T=system.T_ambient,
    nPorts=1,
    use_m_flow_in=true,
    redeclare package Medium = Modelica.Media.Water.ConstantPropertyLiquidWater)
    annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={50,-188})));
  Applications.PressureLoss.ValveFlowModel from_dp4(redeclare package Medium = 
        Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.OverallFlowModel)
    "Calculate mass flow rate from pressure loss" 
    annotation (Placement(transformation(extent={{76,-152},{124,-104}})));

  Applications.PressureLoss.ValveFlowModel from_mflow4(redeclare package Medium
      = Modelica.Media.Water.ConstantPropertyLiquidWater, redeclare model
      FlowModel = 
        FluidDissipation.Examples.Applications.PressureLoss.BaseClasses.Valve.Overall.OverallFlowModel)
    "Calculate pressure loss from mass flow rate" 
    annotation (Placement(transformation(extent={{76,-200},{124,-152}})));

equation
  connect(IN_p.ports[1], from_dp.port_a) annotation (Line(
      points={{60,168},{76,168}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_dp.port_b, OUT_dp.ports[1]) annotation (Line(
      points={{124,168},{180,168}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow.port_b, OUT_mflow.ports[1]) annotation (Line(
      points={{124,128},{180,128}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow.port_a, IN_mflow.ports[1]) annotation (Line(
      points={{76,128},{60,128}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(input_p.y, IN_p.p_in) annotation (Line(
      points={{21,166},{28,166},{28,176},{38,176}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(IN_p1.ports[1], from_dp1.port_a) annotation (Line(
      points={{-138,88},{-130,88},{-130,96},{-122,96}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_dp1.port_b, OUT_dp1.ports[1]) annotation (Line(
      points={{-74,96},{-46,96},{-46,88},{-18,88}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow1.port_b, OUT_mflow1.ports[1]) annotation (Line(
      points={{-74,48},{-18,48}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow1.port_a, IN_mflow1.ports[1]) annotation (Line(
      points={{-122,48},{-138,48}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(input_p1.y, IN_p1.p_in) annotation (Line(
      points={{-177,86},{-170,86},{-170,96},{-160,96}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(IN_p2.ports[1], from_dp2.port_a) annotation (Line(
      points={{60,8},{68,8},{68,16},{76,16}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_dp2.port_b, OUT_dp2.ports[1]) annotation (Line(
      points={{124,16},{152,16},{152,8},{180,8}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow2.port_b, OUT_mflow2.ports[1]) annotation (Line(
      points={{124,-32},{180,-32}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow2.port_a, IN_mflow2.ports[1]) annotation (Line(
      points={{76,-32},{60,-32}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(input_p2.y, IN_p2.p_in) annotation (Line(
      points={{21,6},{28,6},{28,16},{38,16}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(IN_p3.ports[1], from_dp3.port_a) annotation (Line(
      points={{-140,-70},{-132,-70},{-132,-62},{-124,-62}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_dp3.port_b, OUT_dp3.ports[1]) annotation (Line(
      points={{-76,-62},{-48,-62},{-48,-70},{-20,-70}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow3.port_b, OUT_mflow3.ports[1]) annotation (Line(
      points={{-76,-110},{-20,-110}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow3.port_a, IN_mflow3.ports[1]) annotation (Line(
      points={{-124,-110},{-140,-110}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(input_p3.y, IN_p3.p_in) annotation (Line(
      points={{-179,-72},{-172,-72},{-172,-62},{-162,-62}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(IN_p4.ports[1], from_dp4.port_a) annotation (Line(
      points={{60,-148},{68,-148},{68,-128},{76,-128}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_dp4.port_b, OUT_dp4.ports[1]) annotation (Line(
      points={{124,-128},{152,-128},{152,-148},{180,-148}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow4.port_b, OUT_mflow4.ports[1]) annotation (Line(
      points={{124,-176},{152,-176},{152,-188},{180,-188}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(from_mflow4.port_a, IN_mflow4.ports[1]) annotation (Line(
      points={{76,-176},{68,-176},{68,-188},{60,-188}},
      color={0,127,255},
      smooth=Smooth.None));
  connect(input_p4.y, IN_p4.p_in) annotation (Line(
      points={{21,-150},{28,-150},{28,-140},{38,-140}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(input_mflow.y, IN_mflow.m_flow_in) annotation (Line(
      points={{-179,-2},{-174,-2},{-174,136},{40,136}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(input_mflow.y, IN_mflow1.m_flow_in) annotation (Line(
      points={{-179,-2},{-174,-2},{-174,56},{-158,56}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(input_mflow.y, IN_mflow2.m_flow_in) annotation (Line(
      points={{-179,-2},{-174,-2},{-174,-24},{40,-24}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(input_mflow.y, IN_mflow3.m_flow_in) annotation (Line(
      points={{-179,-2},{-174,-2},{-174,-102},{-160,-102}},
      color={0,0,127},
      smooth=Smooth.None));
  connect(input_mflow.y, IN_mflow4.m_flow_in) annotation (Line(
      points={{-179,-2},{-174,-2},{-174,-180},{40,-180}},
      color={0,0,127},
      smooth=Smooth.None));
  annotation (
    Documentation(info="<html>
</html>
"), experiment(NumberOfIntervals=5000),
    experimentSetupOutput,
    Diagram(coordinateSystem(preserveAspectRatio=true, extent={{-200,-200},{200,
            200}}), graphics={
        Text(
          extent={{-50,202},{32,188}},
          lineColor={0,0,255},
          textString="SeveralTestCases"),
        Text(
          extent={{-90,158},{-8,144}},
          lineColor={0,0,255},
          textString="CurvedBend"),
        Text(
          extent={{16,72},{98,58}},
          lineColor={0,0,255},
          textString="MitreBend"),
        Text(
          extent={{-100,-6},{-18,-20}},
          lineColor={0,0,255},
          textString="RectangularChannel"),
        Text(
          extent={{10,-83},{92,-97}},
          lineColor={0,0,255},
          textString="StraightPipe"),
        Text(
          extent={{-84,-165},{-2,-179}},
          lineColor={0,0,255},
          textString="BallValve")}),
    Icon(coordinateSystem(preserveAspectRatio=true, extent={{-200,-200},{200,
            200}})));
end SeveralTestCases;
